<?php
/**
 * @package         Regular Labs Library
 * @version         23.3.19307
 * 
 * @author          Peter van Westen <info@regularlabs.com>
 * @link            http://regularlabs.com
 * @copyright       Copyright © 2023 Regular Labs All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

use Joomla\CMS\Language\Text as JText;
use RegularLabs\Library\StringHelper as RL_String;

if ( ! is_file(JPATH_LIBRARIES . '/regularlabs/autoload.php'))
{
    return;
}

require_once JPATH_LIBRARIES . '/regularlabs/autoload.php';

JFormHelper::loadFieldClass('text');

class JFormFieldRL_Text extends JFormFieldText
{
    public $type = 'Text';

    public function setup(SimpleXMLElement $element, $value, $group = null)
    {
        $this->element = $element;

        $element['label']                = $this->prepareText($element['label']);
        $element['description']          = $this->prepareText($element['description']);
        $element['hint']                 = $this->prepareText($element['hint']);
        $element['translateDescription'] = false;

        return parent::setup($element, $value, $group);
    }

    private function get($val, $default = '')
    {
        if ( ! isset($this->params[$val]) || (string) $this->params[$val] == '')
        {
            return $default;
        }

        return (string) $this->params[$val];
    }

    private function prepareText($string = '')
    {
        $string = trim($string);

        if ($string == '')
        {
            return '';
        }

        // variables
        $var1 = JText::_($this->get('var1'));
        $var2 = JText::_($this->get('var2'));
        $var3 = JText::_($this->get('var3'));
        $var4 = JText::_($this->get('var4'));
        $var5 = JText::_($this->get('var5'));

        $string = JText::sprintf($string, $var1, $var2, $var3, $var4, $var5);
        $string = trim(RL_String::html_entity_decoder($string));
        $string = str_replace('&quot;', '"', $string);
        $string = str_replace('span style="font-family:monospace;"', 'span class="rl-code"', $string);

        return $string;
    }
}
